@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Acme::CPANLists;
 
-our $DATE = '2015-10-23'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -58,7 +58,9 @@ sub weave_section {
 }
 
 1;
-# ABSTRACT: Create "AUTHOR LISTS" and "MODULE LISTS" POD sections from @Author_Lists and @Module_Lists
+# ABSTRACT: Plugin to use when building Acme::CPANLists::* distribution
+
+
 
 __END__
 
@@ -68,11 +70,11 @@ __END__
 
 =head1 NAME
 
-Pod::Weaver::Plugin::Acme::CPANLists - Create "AUTHOR LISTS" and "MODULE LISTS" POD sections from @Author_Lists and @Module_Lists
+Pod::Weaver::Plugin::Acme::CPANLists - Plugin to use when building Acme::CPANLists::* distribution
 
 =head1 VERSION
 
-This document describes version 0.04 of Pod::Weaver::Plugin::Acme::CPANLists (from Perl distribution Pod-Weaver-Plugin-Acme-CPANLists), released on 2015-10-23.
+This document describes version 0.05 of Pod::Weaver::Plugin::Acme::CPANLists (from Perl distribution Pod-Weaver-Plugin-Acme-CPANLists), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -82,6 +84,17 @@ In your C<weaver.ini>:
 
 =head1 DESCRIPTION
 
+This plugin is used when building Acme::CPANLists::* distributions. It currently
+does the following:
+
+=over
+
+=item * Create "AUTHOR LISTS" POD section from C<@Author_Lists>
+
+=item * Create "MODULE LISTS" POD section from C<@Module_Lists>
+
+=back
+
 =for Pod::Coverage weave_section
 
 =head1 HOMEPAGE
@@ -106,9 +119,10 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
